@@ -13,14 +13,12 @@ def create(name, profile):
     """Create a new slai project."""
 
     runtime = detect_runtime()
-    credentials = detect_credentials(runtime=runtime, profile=profile)
+    credentials = detect_credentials(runtime=runtime, profile_name=profile)
 
     try:
         pg = project_generator.ProjectGenerator(
             project_name=name,
-            client_id=credentials["client_id"],
-            client_secret=credentials["client_secret"],
-            profile=profile,
+            credentials=credentials,
         )
     except ProjectExistsException:
         log.warn(f"Project '{name}' already exists.")
