@@ -1,13 +1,11 @@
-import click
-import time
 import os
 import shutil
 
 from columnar import columnar
 from pathlib import Path
 
-from slai.clients.model import ModelClient
-from slai.clients.cli import SlaiCliClient
+from slai.clients.model import get_model_client
+from slai.clients.cli import get_cli_client
 from slai.clients.project import get_project_client
 from slai_cli.create.local_config_helper import LocalConfigHelper
 from slai_cli import log
@@ -60,16 +58,12 @@ def checkout_model_version(model_name, version_name=None):
 
     project_client = get_project_client(project_name=None)
     project_name = project_client.get_project_name()
-    credentials = project_client.get_credentials()
-    model_client = ModelClient(model_name=model_name, project_name=project_name)
 
-    slai_client = SlaiCliClient(
-        client_id=credentials["client_id"],
-        client_secret=credentials["client_secret"],
-    )
+    model_client = get_model_client(model_name=model_name, project_name=project_name)
+    cli_client = get_cli_client()
 
     model_id = model_client.model["id"]
-    model_versions = slai_client.list_model_versions(model_id=model_id)
+    model_versions = cli_client.list_model_versions(model_id=model_id)
     version_names = {mv["name"]: mv["id"] for mv in model_versions}
 
     local_config_helper = LocalConfigHelper()
@@ -92,7 +86,7 @@ def checkout_model_version(model_name, version_name=None):
 
         # otherwise, create a new model version with that name
         else:
-            model_version = slai_client.create_model_version(
+            model_version = cli_client.create_model_version(
                 model_id=model_id, name=version_name
             )
             model_version_id_to_checkout = model_version["id"]
