@@ -33,3 +33,10 @@ class DriveClient:
             parent_ids=[project_google_drive_folder_id],
         )
         return model_google_drive_folder_id
+
+    def create_project_folder(self, folder_name):
+        project_folder_google_drive_id = self.client.create_folder(
+            name=f"{folder_name}",
+            parent_ids=[],
+        )
+        return project_folder_google_drive_id
